@@ -4,11 +4,15 @@ from pyroma import projectdata, distributiondata, pypidata
 from pyroma.ratings import rate
 from pkg_resources import resource_filename, resource_string
 
+long_description = resource_string(
+    __name__, os.path.join('testdata', 'complete', 'README.txt'))
+if not isinstance(long_description, str):
+    long_description = long_description.decode()
+
 COMPLETE = {'name': 'complete',
             'version': '1.0',
             'description': 'This is a test package for pyroma.',
-            'long_description': resource_string(
-                __name__, os.path.join('testdata', 'complete', 'README.txt')),
+            'long_description': long_description,
             'classifiers': ['Development Status :: 6 - Mature',
                             'Operating System :: OS Independent',
                             'Programming Language :: Python :: 2.6',],
@@ -25,9 +29,9 @@ COMPLETE = {'name': 'complete',
             'include_package_data': True,
             'zip_safe': True,
             'test_suite': "complete",
-            '_imports': set(['unittest', 'external5', 'external2',
-                             'external3', 'external1', 'external4',]
-                            ),
+            #'_imports': set(['unittest', 'external5', 'external2',
+                             #'external3', 'external1', 'external4',]
+                            #),
             }
 
 class RatingsTest(unittest.TestCase):
@@ -59,7 +63,6 @@ class RatingsTest(unittest.TestCase):
             'Your package does not have license data', 
             "It's not specified if this package is zip_safe or not, which is usually an oversight. You should specify it, as it defaults to True, which you probably do not want.",
             "Setuptools and Distribute support running tests. By specifying a test suite, it's easy to find and run tests both for automated tools and humans.",
-            'Did you forget to declare the following dependencies?: external1',
         ]))
 
     def test_distribute(self):
@@ -67,9 +70,8 @@ class RatingsTest(unittest.TestCase):
         data = pypidata.get_data('distribute')
         rating = rate(data)
         
-        self.assertEqual(rating, (7, [
+        self.assertEqual(rating, (9, [
             'The classifiers should specify what minor versions of Python you support as well as what major version',
-            'Did you forget to declare the following dependencies?: win32com, Pyrex',
         ]))
 
 class ProjectDataTest(unittest.TestCase):
